@@ -16,16 +16,23 @@ class RobotModelArtist(GHArtist, RobotModelArtist):
 
     Parameters
     ----------
-    model : :class:`compas.robots.RobotModel`
+    model : :class:`~compas.robots.RobotModel`
         Robot model.
+    **kwargs : dict, optional
+        Additional keyword arguments.
+        See :class:`~compas_ghpython.artists.GHArtist` and :class:`~compas.artists.RobotModelArtist` for more info.
+
     """
 
     def __init__(self, model, **kwargs):
         super(RobotModelArtist, self).__init__(model=model, **kwargs)
 
+    # again not really sure why this is here
     def transform(self, native_mesh, transformation):
         xtransform(native_mesh, transformation)
 
+    # same here
+    # there is no reference to self...
     def create_geometry(self, geometry, name=None, color=None):
         if color:
             color = rgb_to_rgb(color[0], color[1], color[2])
@@ -37,4 +44,11 @@ class RobotModelArtist(GHArtist, RobotModelArtist):
         return mesh
 
     def draw(self):
-        self.draw_visual()
+        """Draw the visual meshes of the robot model.
+
+        Returns
+        -------
+        list[:rhino:`Rhino.Geometry.Mesh`]
+
+        """
+        return self.draw_visual()
